#
# spec file for package postgresql93-libs
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define majorversion 9.3
%define packageversion 93
%define pgname postgresql%packageversion
%define libpq libpq5
%define libecpg libecpg6
%define libpq_so libpq.so.5
%define libecpg_so libecpg.so.6
%define buildmain 0
%define buildlibs 0
%define builddevel 1
%define pgbasedir %_prefix/lib/%pgname
%define pgtestdir %pgbasedir/test
%define pgbindir %pgbasedir/bin
%define pglibdir %pgbasedir/%_lib
%define pgincludedir %_includedir/pgsql
%define pgdatadir %_datadir/%pgname
%define pgdocdir %_docdir/%pgname
%define pgextensiondir %pgdatadir/extension
%define pgmandir %_mandir

Name:           postgresql93-libs

%if %buildmain
BuildRequires:  gettext-devel
BuildRequires:  ncurses-devel
BuildRequires:  pam-devel
BuildRequires:  postgresql-init
BuildRequires:  python-devel
BuildRequires:  readline-devel
BuildRequires:  tcl-devel
BuildRequires:  timezone
BuildRequires:  uuid-devel
BuildRequires:  zlib-devel
# 
%endif

BuildRequires:  fdupes
BuildRequires:  krb5-devel
BuildRequires:  libxslt-devel
BuildRequires:  openldap2-devel
BuildRequires:  openssl-devel
BuildRequires:  pkg-config
BuildRequires:  update-alternatives
#!BuildIgnore:  %pgname
Summary:        Basic Clients and Utilities for PostgreSQL
License:        PostgreSQL
Group:          Productivity/Databases/Tools
Version:        9.3.17
Release:        6.1
%define pg_minor_version %(echo %version | sed -r 's/^([0-9]+\\.[0-9]+).*/\\1/')
Source0:        https://ftp.postgresql.org/pub/source/v%{version}/postgresql-%{version}.tar.bz2
Source3:        postgresql-README.SUSE
Source17:       postgresql-rpmlintrc
Patch1:         postgresql-conf.patch
Patch2:         postgresql-regress.patch
Patch6:         postgresql-testsuite-int8.sql.patch
Patch7:         postgresql-testsuite-seclabel-location.patch
Patch8:         postgresql-testsuite-keep-results-file.patch
Patch9:         postgresql-var-run-socket.patch
Url:            https://www.postgresql.org/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Provides:       postgresql = %version
Requires:       %libpq >= %majorversion
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description
PostgreSQL is an advanced object-relational database management system
that supports an extended subset of the SQL standard, including
transactions, foreign keys, subqueries, triggers, and user-defined
types and functions.

This package contains the basic utility and client programs necessary
to maintain and work with local or remote PostgreSQL databases as well
as manual pages for the SQL commands that PostgreSQL supports. Full
HTML documentation for PostgreSQL can be found in the postgresql-docs
package.

%package -n %libpq
Summary:        Shared Libraries Required for PostgreSQL Clients
Group:          Productivity/Databases/Clients
Provides:       postgresql-libs:%_libdir/libpq.so.5
Obsoletes:      postgresql-libs < %version
# bug437293
%if "%_lib" == "lib64"
Conflicts:      %libpq-32bit < %version
%endif
%ifarch ia64
Conflicts:      %libpq-x86 < %version
%endif
%ifarch ppc64
Obsoletes:      postgresql-libs-64bit
%endif

%description -n %libpq

PostgreSQL is an advanced object-relational database management system
that supports an extended subset of the SQL standard, including
transactions, foreign keys, subqueries, triggers, user-defined types
and functions.

This package provides the client library that most PostgreSQL client
program or language bindings are using.

%package -n %libecpg

Summary:        Shared Libraries Required for PostgreSQL Clients
Group:          Productivity/Databases/Clients
Provides:       postgresql-libs:%_libdir/libecpg.so.6

%description -n %libecpg
PostgreSQL is an advanced object-relational database management system
that supports an extended subset of the SQL standard, including
transactions, foreign keys, subqueries, triggers, user-defined types
and functions.

This package provides the runtime library of the embedded SQL C
preprocessor for PostgreSQL.

%if %builddevel
%package -n %pgname-devel
Summary:        PostgreSQL development header files and libraries
Group:          Development/Libraries/C and C++
Provides:       postgresql-devel = %version
Requires:       %libecpg >= %majorversion
Requires:       %libpq >= %majorversion
Requires(post): update-alternatives
Requires(postun): update-alternatives
# Installation of postgresql??-devel is exclusive
Provides:       postgresql-devel-exclusive = %majorversion
Conflicts:      postgresql-devel-exclusive < %majorversion

%description -n %pgname-devel
PostgreSQL is an advanced object-relational database management system
that supports an extended subset of the SQL standard, including
transactions, foreign keys, subqueries, triggers, and user-defined
types and functions.

This package contains the header files and libraries needed to compile
C applications which will directly interact with a PostgreSQL database
management server and the ECPG Embedded C Postgres preprocessor. You
need to install this package if you want to develop applications in C
which will interact with a PostgreSQL server.

%endif

%if %buildmain

%package server
Summary:        The Programs Needed to Create and Run a PostgreSQL Server
Group:          Productivity/Databases/Servers
PreReq:         /sbin/chkconfig
PreReq:         postgresql = %version
PreReq:         postgresql-init >= %majorversion
Requires:       glibc-locale
Requires:       timezone
Provides:       postgresql-server = %version
Requires(preun): postgresql-init >= %majorversion
Requires(postun): postgresql-init >= %majorversion
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description server
PostgreSQL is an advanced object-relational database management system
that supports an extended subset of the SQL standard, including
transactions, foreign keys, sub-queries, triggers, and user-defined
types and functions.

This package includes the programs needed to create and run a
PostgreSQL server, which will in turn allow you to create and maintain
PostgreSQL databases.

%package test
Summary:        The test suite for PostgreSQL
Group:          Productivity/Databases/Servers
Requires:       postgresql-server = %version

%description test
This package contains the sources and pre-built binaries of various
tests for the PostgreSQL database management system, including
regression tests and benchmarks.

%package docs
Summary:        HTML Documentation for PostgreSQL
Group:          Productivity/Databases/Tools
Provides:       postgresql-docs = %version
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif

%description docs
PostgreSQL is an advanced object-relational database management system
that supports an extended subset of the SQL standard, including
transactions, foreign keys, subqueries, triggers, and user-defined
types and functions.

This package contains the HTML documentation for PostgreSQL. The start
page is: file:///usr/share/doc/packages/%name/html/index.html .
Manual pages for the PostgreSQL SQL statements can be found in the
postgresql package.

%package contrib
Summary:        Contributed Extensions and Additions to PostgreSQL
Group:          Productivity/Databases/Tools
#FIXME
PreReq:         %pgname-server = %version
Provides:       postgresql-contrib = %version
Requires(post): update-alternatives

%description contrib
PostgreSQL is an advanced object-relational database management system
that supports an extended subset of the SQL standard, including
transactions, foreign keys, subqueries, triggers, and user-defined
types and functions.

The postgresql-contrib package includes extensions and additions that
are distributed along with the PostgreSQL sources, but are not (yet)
officially part of the PostgreSQL core.

Documentation for the modules contained in this package can be found in
/usr/share/doc/packages/postgresql/contrib.

%package plperl
Summary:        The PL/Tcl, PL/Perl, and  PL/Python procedural languages for PostgreSQL
Group:          Productivity/Databases/Servers
Requires:       perl = %perl_version
Provides:       postgresql-plperl = %version
#FIXME
Requires:       %pgname-server = %version

%description plperl
This package contains the the PL/Tcl, PL/Perl, and PL/Python procedural
languages for the back-end.  With these modules one can use Perl,
Python, and Tcl to write stored procedures, functions and triggers.

PostgreSQL also offers the builtin procedural language PL/SQL.

%package plpython
Summary:        The PL/Python Procedural Languages for PostgreSQL
Group:          Productivity/Databases/Servers
Provides:       postgresql-plpython = %version
#FIXME
Requires:       %pgname-server = %version
Requires:       python

%description plpython
PostgreSQL is an advanced object-relational database management system
that supports an extended subset of the SQL standard, including
transactions, foreign keys, subqueries, triggers, and user-defined
types and functions.

This package contains the PL/Python procedural language for PostgreSQL.
With this module one can use Python to write stored procedures,
functions, and triggers.

PostgreSQL also offers the built-in procedural language PL/SQL which is
included in the postgresql-server package.

%package pltcl
Summary:        PL/Tcl Procedural Language for PostgreSQL
Group:          Productivity/Databases/Tools
Provides:       postgresql-pltcl = %version
#FIXME
Requires:       %pgname-server = %version
Requires:       tcl

%description pltcl
PostgreSQL is an advanced object-relational database management system
that supports an extended subset of the SQL standard, including
transactions, foreign keys, subqueries, triggers, and user-defined
types and functions.

This package contains the PL/Tcl procedural language for PostgreSQL. 
With thie module one can use Tcl to write stored procedures, functions,
and triggers.

PostgreSQL also offers the built-in procedural language PL/SQL which is
included in the postgresql-server package.

%endif

%prep
%setup -q -n postgresql-%version
# Keep the timestamp of configure, because patching it would otherwise
# confuse PostgreSQL's build system
touch -r configure tmp
%patch1
%patch2
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
touch -r tmp configure
rm tmp
find src/test/ -name '*.orig' -delete
find -name .gitignore -delete

%build
PACKAGE_TARNAME=%name %configure \
        --bindir=%pgbindir \
        --libdir=%pglibdir \
        --includedir=%pgincludedir \
        --datadir=%pgdatadir \
        --docdir=%pgdocdir \
        --mandir=%pgmandir \
        --disable-rpath \
        --enable-nls \
        --enable-thread-safety \
        --enable-integer-datetimes \
%if %buildmain
        --with-python \
        --with-perl \
        --with-tcl \
        --with-tclconfig=%_libdir \
        --with-pam \
        --with-ossp-uuid \
        --with-libxml \
        --with-libxslt \
%else
        --without-readline \
%endif
        --with-openssl \
        --with-ldap \
%if 0%{?suse_version} > 910
        --with-gssapi \
        --with-krb5 \
%endif
        --with-system-tzdata=/usr/share/zoneinfo
%if !%buildmain
make -C src/backend %{?_smp_mflags} libpq-recursive
%if %builddevel
make -C src/port %{?_smp_mflags} libpgport.a
make -C src/common %{?_smp_mflags} libpgcommon.a
make -C src/interfaces/ecpg/preproc %{?_smp_mflags}
make -C src/bin/pg_config %{?_smp_mflags} pg_config
%endif
%if %buildlibs || %builddevel
make -C src/interfaces %{?_smp_mflags}
%endif
%else
# {{{ build the test package
make -C src/test/regress all
# }}}
make %{?_smp_mflags} PACKAGE_TARNAME=%name world
%ifnarch %arm
%if 0%{?suse_version} > 910

%check
#
# Run the regression tests.
#
make check || {
  for f in src/test/regress/log/* {,src/test/regress/}regression.diffs; do
    if test -f $f; then
	cat $f
    fi
  done
  exit 1
}
%endif
%endif
%endif

%install
%if %buildmain
make DESTDIR=%buildroot PACKAGE_TARNAME=%name install install-docs
# {{{ the test package
mkdir -p %buildroot%pgtestdir/regress
install -sm 0755 contrib/spi/{refint.so,autoinc.so} %buildroot%pgtestdir/regress
install -sm 0755 src/test/regress/{pg_regress,regress.so,dummy_seclabel.so} %buildroot%pgtestdir/regress
for i in  src/test/regress/{data,expected,input,output,sql}; do
	cp -r $i %buildroot%pgtestdir/regress/
done
install -m 0644 src/test/regress/{serial,parallel}_schedule %buildroot%pgtestdir/regress
# }}}
%endif
%if %builddevel && !%buildmain
SUBINSTALL=install
install -d %buildroot%pgmandir/man1
install -m644 doc/src/sgml/man1/{ecpg,pg_config}.1 %buildroot%pgmandir/man1
%else
SUBINSTALL=uninstall
rm -f %buildroot%pgmandir/*/ecpg*
rm -f %buildroot%pgmandir/*/pg_config*
%endif
# Install them for postgresql-libs and uninstall them for postgresql
make -C src DESTDIR=%buildroot $SUBINSTALL-local
make -C src/pl/plpgsql/src DESTDIR=%buildroot $SUBINSTALL-headers
for dir in \
        config \
        src/bin/pg_config \
        src/interfaces \
        src/include \
        src/makefiles \
        src/port \
        src/common \
        src/test/regress
do
        make -C $dir DESTDIR=%buildroot $SUBINSTALL
done

%if %builddevel
# The client libraries go to libdir
mkdir -p %buildroot/%_libdir
ls %buildroot%pglibdir/lib* |
   grep -v walreceiver |
   xargs mv -t %buildroot/%_libdir
mv %buildroot%pglibdir/pkgconfig %buildroot%_libdir
sed -i 's, -L%pglibdir,,' %buildroot%_libdir/pkgconfig/*.pc
%endif
# Don't ship static libraries,
# libpgport.a and libpgcommon.a are needed, though.
rm -f $(ls %buildroot/%_libdir/*.a | grep -F -v -e libpgport.a -e libpgcommon.a)
%if %buildmain
#
# Install and collect the contrib stuff
#
touch flag; sleep 1 # otherwise we have installed files that are not newer than flag
make DESTDIR=%buildroot -C contrib install
find %buildroot -type f -cnewer flag -printf "/%%P\n" |
     grep -v -e %_docdir -e %pgbindir > contrib.files
rm flag
install -d -m 750 %buildroot/var/lib/pgsql
install -d -m755 %buildroot%pgdocdir
cp doc/KNOWN_BUGS doc/MISSING_FEATURES COPYRIGHT \
   README HISTORY doc/bug.template %buildroot%pgdocdir
cp -a %SOURCE3 %buildroot%pgdocdir/README.SUSE
%endif
# Use versioned names for the man pages:
for f in %buildroot%pgmandir/man*/*; do
        mv $f ${f}pg%packageversion
done

%if %builddevel
# Make sure we can also link agaist newer versions
pushd %buildroot%_libdir
for f in *.so; do
    ln -sf $f.? $f
done
popd
%if %buildlibs
%find_lang libpq5-%{pg_minor_version} libpq.lang
%find_lang ecpglib6-%{pg_minor_version} libecpg.lang
%else
rm %buildroot/usr/share/locale/*/*/libpq5*
rm %buildroot/usr/share/locale/*/*/ecpglib6*
rm %buildroot%_libdir/lib*.so.*
rm %buildroot%pgdatadir/pg_service.conf.sample
%endif
%endif
cat > alternatives <<"EOF"
shopt -s nullglob
for FILE in %pgbindir/*; do
        NAME=$(basename $FILE)
        DIR=%_bindir
        SLAVES="$SLAVES --slave $DIR/$NAME $NAME $FILE"
done
if test -n "$SLAVES"; then
	update-alternatives --quiet --install \
        /usr/lib/postgresql postgresql %pgbasedir %packageversion \
        $SLAVES
fi
EOF
mkdir -p %buildroot{%_bindir,%_mandir/man1}
mkdir -p %buildroot/etc/alternatives
genlists ()
{
    # usage: genlists packagename basenames
    PKG=$1
    shift
    for f in $@
    do
        BIN=%_bindir/$f
        ALTBIN=/etc/alternatives/$f
        PGBIN=%pgbindir/$f
        MAN=%pgmandir/man1/$f.1*

        touch %buildroot$ALTBIN
        ln -s $ALTBIN %buildroot$BIN

        echo "$PGBIN" >> $PKG.files
        echo "$BIN" >> $PKG.files
        echo "%ghost $ALTBIN" >> $PKG.files
        test -e %buildroot$MAN &&
            echo "%doc $MAN" >> $PKG.files
        %find_lang $f-%pg_minor_version $PKG.files ||:
    done
}
%if %buildmain
genlists main \
        createdb clusterdb createlang createuser dropdb droplang \
        dropuser pg_dump pg_dumpall pg_restore psql vacuumdb \
        reindexdb pg_basebackup pg_receivexlog pg_isready
%find_lang plpgsql-%pg_minor_version main.files
%find_lang pgscripts-%pg_minor_version main.files

genlists server \
        initdb pg_ctl pg_controldata pg_resetxlog postgres postmaster

genlists contrib \
        oid2name pg_archivecleanup pg_standby pg_test_fsync pg_upgrade \
        pgbench vacuumlo pg_test_timing pg_xlogdump
for pl in plperl plpython pltcl; do
    %find_lang $pl-%{pg_minor_version} $pl.lang
done
%endif
ln -s /etc/alternatives/postgresql %buildroot/usr/lib/postgresql
touch %buildroot/etc/alternatives/postgresql
%if %builddevel
genlists devel \
        pg_config ecpg
%endif
%fdupes %buildroot

%if %buildmain

%postun
if test "$1" == 0; then
    update-alternatives --remove postgresql %pgbasedir
fi

%post -p /bin/bash -f alternatives

%post server -f alternatives

%preun server
# Stop only when we are uninstalling the currently running version
PID=$(pidof -s postgres) || :
if test -n "$PID" -a -x /etc/init.d/postgresql; then
    BIN=$(readlink /proc/$PID/exe)
    DIR=$(dirname ${BIN% *})
    if test "$DIR" = "%pgbindir"; then
        %stop_on_removal postgresql
    fi
fi

%postun server -f alternatives
# Restart only when we are updating the currently running version
# or from the old packaging scheme
PID=$(pidof -s postgres) || :
if test -n "$PID" -a -x /etc/init.d/postgresql; then
    BIN=$(readlink /proc/$PID/exe)
    DIR=$(dirname ${BIN% *})
    if test "$DIR" = "%pgbindir" -o "$DIR" = "%_bindir"; then
        %restart_on_update postgresql
    fi
fi

%post contrib -f alternatives

%postun contrib -f alternatives

%endif

%if %builddevel

%post -n %pgname-devel -f alternatives

%postun -n %pgname-devel -f alternatives
%endif

%if %buildlibs
%post -n %libpq -p /sbin/ldconfig

%postun -n %libpq -p /sbin/ldconfig

%post -n %libecpg -p /sbin/ldconfig

%postun -n %libecpg -p /sbin/ldconfig
%endif

%if %buildmain

%files -f main.files
%defattr(-,root,root)
%dir %pgbindir
%doc %pgmandir/man7/*
%docdir %pgdocdir
%dir %pgdocdir
%pgdocdir/[[:upper:]]*
%pgdocdir/bug.template
%dir %pglibdir
/usr/lib/postgresql
%ghost /etc/alternatives/postgresql

%files test
%defattr(-,root,root,-)
%pgtestdir

%files docs
%defattr(-,root,root)
%doc %pgmandir/man3/*
%docdir %pgdocdir
%dir %pgdocdir
%pgdocdir/html

%files contrib -f contrib.files
%defattr(-,root,root)
%docdir %pgdocdir
%dir %pgdocdir
%pgdocdir/extension
%dir %pgdatadir
/usr/lib/postgresql
%ghost /etc/alternatives/postgresql

%files server -f server.files
%defattr(-,root,root)
%dir %pgbasedir
%dir %pgextensiondir
%dir %pglibdir
%pglibdir/plpgsql.so
%pglibdir/dict_snowball.so
%pgdatadir/tsearch_data
%exclude %pgdatadir/tsearch_data/*.rules
%dir %pgdatadir
/usr/lib/postgresql
%ghost /etc/alternatives/postgresql
%pgdatadir/timezone*
%pgdatadir/*.*
%if %buildlibs
%exclude %pgdatadir/pg_service.conf.sample
%endif
%exclude %pgdatadir/*.pltcl
%pglibdir/*_and_*.so
%pglibdir/euc2004_sjis2004.so
%pglibdir/libpqwalreceiver.so
%pgextensiondir/plpgsql*
%attr(750,postgres,postgres) %dir /var/lib/pgsql

%files pltcl -f pltcl.lang
%defattr(-,root,root)
%pgextensiondir/pltcl*
%pglibdir/pltcl.so
%pgdatadir/*.pltcl
%pgbindir/pltcl*

%files plperl -f plperl.lang
%defattr(-,root,root)
%pgextensiondir/plperl*
%pglibdir/plperl.so

%files plpython -f plpython.lang
%defattr(-,root,root)
%pgextensiondir/plpython*
%pglibdir/plpython*.so

%endif
%if %buildlibs

%files -n %libpq -f libpq.lang
%defattr(-,root,root)
%dir %pgbasedir
%dir %pgdatadir
%_libdir/libpq.so.*
%pgdatadir/pg_service.conf.sample

%files -n %libecpg -f libecpg.lang
%defattr(-,root,root)
%_libdir/libecpg*.so.*
%_libdir/libpgtypes.so.*

%endif

%if %builddevel

%files -n %pgname-devel -f devel.files
%defattr(-,root,root)
%dir %pgbasedir
%dir %pgbindir
%dir %pglibdir
%_libdir/pkgconfig/*
%_libdir/lib*.a
%_libdir/lib*.so
%pglibdir/pgxs
%pgincludedir
/usr/lib/postgresql
%ghost /etc/alternatives/postgresql

%endif

%changelog
* Tue May  9 2017 max@suse.com
- Update to version 9.3.17:
  * https://www.postgresql.org/docs/9.3/static/release-9-3-16.html
  * CVE-2017-7486, bsc#1037624: Restrict visibility of
    pg_user_mappings.umoptions, to protect passwords stored as
    user mapping options.
    !!! Manual action is needed to fix this in existing databases
    !!! See upstream release notes for details.
  * CVE-2017-7485, bsc#1038293: recognize PGREQUIRESSL variable
    again.
  * CVE-2017-7484, bsc#1037603: Prevent exposure of statistical
    information via leaky operators.
  * Obsoletes postgresql-9.3.16-fix-timezone-tests.patch
- Move the timezone requirement to the server package as it was
  originally intended.
- Sync spec file with postgresql96.
- Merge Factory and SLE-12.
* Wed Mar 15 2017 astieger@suse.com
- fix tests with timezone 2017a bsc#1029547
  postgresql-9.3.16-fix-timezone-tests.patch
* Thu Feb  9 2017 mrueckert@suse.de
- Update to version 9.3.16:
  - Build corruption with CREATE INDEX CONCURRENTLY
  - Fixes for visibility and write-ahead-log stability
  For the full release notes, see:
  https://www.postgresql.org/docs/9.3/static/release-9-3-16.html
* Thu Dec  8 2016 fweiss@suse.com
- Update to version 9.3.15:
  * Fix WAL-logging of truncation of relation free space maps and
    visibility maps
  * Fix SELECT FOR UPDATE/SHARE to correctly lock tuples that have
    been updated by a subsequently-aborted transaction
  * Fix EvalPlanQual rechecks involving CTE scans
  * Fix improper repetition of previous results from hashed
    aggregation in a subquery
  * Fix EXPLAIN to emit valid XML when track_io_timing is on
  * For the other bug fixes, see the release notes:
    https://www.postgresql.org/docs/9.3/static/release-9-3-15.html
* Thu Sep 15 2016 fweiss@suse.com
- Added "Requires: timezone" to Server Package (bsc#973660)
* Fri Aug 12 2016 fweiss@suse.com
- Update to version 9.3.14:
  * Fix possible mis-evaluation of nested CASE-WHEN expressions
    (CVE-2016-5423, bsc#993454)
  * Fix client programs' handling of special characters in database
    and role names (CVE-2016-5424, bsc#993453)
  * Fix corner-case misbehaviors for IS NULL/IS NOT NULL applied
    to nested composite values
  * Make the inet and cidr data types properly reject IPv6
    addresses with too many colon-separated fields
  * Prevent crash in close_ps() (the point ## lseg operator) for
    NaN input coordinates
  * Fix several one-byte buffer over-reads in to_number()
  * Avoid unsafe intermediate state during expensive paths through
    heap_update()
  * For the other bug fixes, see the release notes:
    https://www.postgresql.org/docs/9.3/static/release-9-3-14.html
* Thu May 19 2016 mrueckert@suse.de
- Bugfix release 9.3.13
  This update fixes several problems which caused downtime for
  users, including:
  - Clearing the OpenSSL error queue before OpenSSL calls,
    preventing errors in SSL connections, particularly when using
    the Python, Ruby or PHP OpenSSL wrappers
  - Fixed the "failed to build N-way joins" planner error
  - Fixed incorrect handling of equivalence in multilevel nestloop
    query plans, which could emit rows which didn't match the WHERE
    clause.
  - Prevented two memory leaks with using GIN indexes, including a
    potential index corruption risk.
  The release also includes many other bug fixes for reported
  issues, many of which affect all supported versions:
  - Fix corner-case parser failures occurring when
    operator_precedence_warning is turned on
  - Prevent possible misbehavior of TH, th, and Y,YYY format codes
    in to_timestamp()
  - Correct dumping of VIEWs and RULEs which use ANY (array) in a
    subselect
  - Disallow newlines in ALTER SYSTEM parameter values
  - Avoid possible misbehavior after failing to remove a tablespace
    symlink
  - Fix crash in logical decoding on alignment-picky platforms
  - Avoid repeated requests for feedback from receiver while
    shutting down walsender
  - Multiple fixes for pg_upgrade
  - Support building with Visual Studio 2015
  - This update also contains tzdata release 2016d, with updates
    for Russia, Venezuela, Kirov, and Tomsk.
  http://www.postgresql.org/docs/current/static/release-9-3-13.html
* Wed May  4 2016 mrueckert@suse.de
- Bugfix release 9.3.12:
  - Fix two bugs in indexed ROW() comparisons
  - Avoid data loss due to renaming files
  - Prevent an error in rechecking rows in SELECT FOR UPDATE/SHARE
  - Fix bugs in multiple json_ and jsonb_ functions
  - Log lock waits for INSERT ON CONFLICT correctly
  - Ignore recovery_min_apply_delay until reaching a consistent
    state
  - Fix issue with pg_subtrans XID wraparound
  - Fix assorted bugs in Logical Decoding
  - Fix planner error with nested security barrier views
  - Prevent memory leak in GIN indexes
  - Fix two issues with ispell dictionaries
  - Avoid a crash on old Windows versions
  - Skip creating an erroneous delete script in pg_upgrade
  - Correctly translate empty arrays into PL/Perl
  - Make PL/Python cope with identifier names
- For the full release notes, see:
  http://www.postgresql.org/docs/9.3/static/release-9-3-12.html
* Fri Feb 12 2016 max@suse.com
- Security and bugfix release 9.3.11:
  * Fix infinite loops and buffer-overrun problems in regular
    expressions (CVE-2016-0773, bsc#966436).
  * Fix regular-expression compiler to handle loops of constraint
    arcs (CVE-2007-4772).
  * Prevent certain PL/Java parameters from being set by
    non-superusers (CVE-2016-0766, bsc#966435).
  * Fix many issues in pg_dump with specific object types
  * Prevent over-eager pushdown of HAVING clauses for
    GROUPING SETS
  * Fix deparsing error with ON CONFLICT ... WHERE clauses
  * Fix tableoid errors for postgres_fdw
  * Prevent floating-point exceptions in pgbench
  * Make \det search Foreign Table names consistently
  * Fix quoting of domain constraint names in pg_dump
  * Prevent putting expanded objects into Const nodes
  * Allow compile of PL/Java on Windows
  * Fix "unresolved symbol" errors in PL/Python execution
  * Allow Python2 and Python3 to be used in the same database
  * Add support for Python 3.5 in PL/Python
  * Fix issue with subdirectory creation during initdb
  * Make pg_ctl report status correctly on Windows
  * Suppress confusing error when using pg_receivexlog with older
    servers
  * Multiple documentation corrections and additions
  * Fix erroneous hash calculations in gin_extract_jsonb_path()
- For the full release notse, see:
  http://www.postgresql.org/docs/9.3/static/release-9-3-11.html
* Mon Oct 12 2015 max@suse.com
- Security and bugfix release 9.3.10:
  * CVE-2015-5289, bsc#949670: json or jsonb input values
    constructed from arbitrary user input can crash the PostgreSQL
    server and cause a denial of service.
  * CVE-2015-5288, bsc#949669: The crypt() function included with
    the optional pgCrypto extension could be exploited to read a
    few additional bytes of memory. No working exploit for this
    issue has been developed.
- For the full release notse, see:
  http://www.postgresql.org/docs/current/static/release-9-3-10.html
- Move systemd related stuff and user creation to postgresql-init.
- Remove some obsolete %%suse_version conditionals.
- Adjust build time dependencies.
- Fix some more rpmlint warnings.
- Relax dependency on libpq to major version.
* Mon Sep 28 2015 max@suse.com
- Move ~postgres/.bash_profile to postgresql-server to avoid a
  file conflict between the versioned server packages.
* Thu Aug 20 2015 max@suse.com
- Merge openSUSE and SLE12 packages (bsc#941886).
- Merge .changes, remove duplicate entries and fix syntax
  violations at the very bottom.
- postgresql-sle10-timestamptz.patch is obsolete.
- remove baselibs.conf, because we don't build the libarries any
  longer.
- Bugfix release 9.3.9:
  * Fix possible failure to recover from an inconsistent database
    state. See full release notes for details.
  * Fix rare failure to invalidate relation cache init file.
  * Avoid deadlock between incoming sessions and CREATE/DROP
    DATABASE.
  * Improve planner's cost estimates for semi-joins and anti-joins
    with inner indexscans
- For the full release notse, see:
  http://www.postgresql.org/docs/9.3/static/release-9-3-9.html
* Wed Jun  3 2015 max@suse.com
- Bugfix release 9.3.8:
  * Avoid failures while fsync'ing data directory during crash
    restart.
  * Fix pg_get_functiondef() to show functions' LEAKPROOF
    property, if set.
  * Allow libpq to use TLS protocol versions beyond v1.
- For the full release notse, see:
  http://www.postgresql.org/docs/9.3/static/release-9-3-8.html
* Fri May 22 2015 max@suse.com
- Security and bugfix release 9.3.7:
  * CVE-2015-3165, bsc#931972: Avoid possible crash when client
    disconnects just before the authentication timeout expires.
  * CVE-2015-3166, bsc#931973: Consistently check for failure of the
  * printf() family of functions.
  * CVE-2015-3167, bsc#931974: In contrib/pgcrypto, uniformly report
    decryption failures as "Wrong key or corrupt data"
  * Protect against wraparound of multixact member IDs.
- For the full release notse, see:
  http://www.postgresql.org/docs/9.3/static/release-9-3-7.html
* Fri Feb 20 2015 max@suse.com
- Security and bugfix release 9.3.6 (bnc#916953):
  * Fix buffer overruns in to_char() (CVE-2015-0241).
  * Fix buffer overrun in replacement *printf() functions
    (CVE-2015-0242).
  * Fix buffer overruns in contrib/pgcrypto (CVE-2015-0243).
  * Fix possible loss of frontend/backend protocol synchronization
    after an error (CVE-2015-0244).
  * Fix information leak via constraint-violation error messages
    (CVE-2014-8161).
  * For the other bug fixes, see the release notes:
    http://www.postgresql.org/docs/9.3/static/release-9-3-6.html
* Thu Feb 19 2015 max@suse.com
- Align spec file with version 9.4 and improve the building of
  libs and devel.
* Thu Jul 31 2014 coolo@suse.com
- postgresql93-libs doesn't require systemd - avoid cycles
* Tue Jul 29 2014 darin@darins.net
- fix systemd unresolvable for SLE_11
  http://en.opensuse.org/openSUSE:Systemd_packaging_guidelines
* Fri Jul 25 2014 ro@suse.de
- add BuildIgnore systemd-mini to fix build
* Fri Jul 25 2014 max@suse.com
- bnc#888564: Move the server socket from /tmp to /var/run to avoid
  problems with clients that use PrivateTmp.
  postgresql-var-run-socket.patch
- Rediff patches.
* Thu Jul 24 2014 max@suse.com
- Update to 9.3.5. The most important changes are:
  * In pg_upgrade, remove pg_multixact files left behind by
    initdb.  If you used a pre-9.3.5 version of pg_upgrade to
    upgrade a database cluster to 9.3, it might have left behind a
    file $PGDATA/pg_multixact/offsets/0000 that should not be
    there and will eventually cause problems in VACUUM. However,
    in common cases this file is actually valid and must not be
    removed.
  * Correctly initialize padding bytes in contrib/btree_gist
    indexes on bit columns. This error could result in incorrect
    query results due to values that should compare equal not
    being seen as equal. Users with GiST indexes on bit or bit
    varying columns should REINDEX those indexes after installing
    this update.
  * Protect against torn pages when deleting GIN list pages.
    This fix prevents possible index corruption if a system crash
    occurs while the page update is being written to disk.
  * Don't clear the right-link of a GiST index page while
    replaying updates from WAL. This error could lead to
    transiently wrong answers from GiST index scans performed in
    Hot Standby.
  * See release notes for a full list of changes:
    http://www.postgresql.org/docs/9.3/static/release-9-3-5.html
    /usr/share/doc/packages/postgresql93/HISTORY
- Remove obsolete postgresql-plperl.patch
* Fri Apr 25 2014 darin@darins.net
- Update to 9.3.4
  * Fix WAL replay of locking an already-updated tuple
  * Restore GIN metapages unconditionally to avoid torn-page risk
  * Avoid race condition in checking transaction commit status during
    receipt of a NOTIFY message
  * Allow materialized views to be referenced in UPDATE and DELETE
    commands
  * Allow regular-expression operators to be terminated early by query
    cancel requests
  * Remove incorrect code that tried to allow OVERLAPS with
    single-element row arguments
  * Avoid getting more than AccessShareLock when de-parsing a rule
    or view
  * Improve performance of index endpoint probes during planning
  * Use non-default selectivity estimates for value IN (list) and
    value operator ANY (array) expressions when the righthand side
    is a stable expression
  * Remove the correct per-database statistics file during DROP DATABASE
  * Fix walsender ping logic to avoid inappropriate disconnects under
    continuous load
  * Fix walsender's failure to shut down cleanly when client is pg_receivexlog
  * See release notes for a full list of changes:
    http://www.postgresql.org/docs/9.3/static/release-9-3-4.html
    /usr/share/doc/packages/postgresql93/HISTORY
* Sun Mar  2 2014 coolo@suse.com
- make postgresql-init a buildrequire. requires(pre) are used during
  build, but do not cause a rebuild trigger. But to make the depencency
  visible for bootstrapping, mark it as real buildrequire
* Fri Feb 21 2014 max@suse.com
- Security and bugfix release 9.3.3:
  * Shore up GRANT ... WITH ADMIN OPTION restrictions
    (CVE-2014-0060, bnc#864845)
  * Prevent privilege escalation via manual calls to PL validator
    functions (CVE-2014-0061, bnc#864846)
  * Avoid multiple name lookups during table and index DDL
    (CVE-2014-0062, bnc#864847)
  * Prevent buffer overrun with long datetime strings
    (CVE-2014-0063, bnc#864850)
  * Prevent buffer overrun due to integer overflow in size
    calculations (CVE-2014-0064, bnc#864851)
  * Prevent overruns of fixed-size buffers (CVE-2014-0065,
    bnc#864852)
  * Avoid crashing if crypt() returns NULL (CVE-2014-0066,
    bnc#864853)
  * Document risks of make check in the regression testing
    instructions (CVE-2014-0067)
  * Rework tuple freezing protocol. The logic for tuple freezing
    was unable to handle some cases involving freezing of
    multixact IDs, with the practical effect that shared row-level
    locks might be forgotten once old enough. Fixing this required
    changing the WAL record format for tuple freezing. While this
    is no issue for standalone servers, when using replication it
    means that STANDBY SERVERS MUST BE UPGRADED TO 9.3.3 OR LATER
    BEFORE THEIR MASTERS ARE.
  * For the other (many!) bug fixes, see the release notes:
    http://www.postgresql.org/docs/9.3/static/release-9-3-3.html
    /usr/share/doc/packages/postgresql93/HISTORY
* Wed Feb 12 2014 dmueller@suse.com
- remove postgresql-tas-aarch64.patch: Fix build for aarch64
* Wed Jan 15 2014 max@suse.com
- Fix handling of alternatives in the file lists.
* Fri Dec  6 2013 kpetsch@suse.com
- Update to version 9.3.2:
  * Fix VACUUM's tests to see whether it can update relfrozenxid
  * Fix multiple bugs in MultiXactId freezing
  * Fix initialization of pg_clog and og_subtrans during hot
    standby startup
  * Fix multiple bugs in update chain traversal
  * Fix dangling-pointer problem in fast-path locking
  * Fix assorted race conditions in timeout management
  * Prevent intra-transaction memory leak when printing range
    values
  * Truncate pg_multixact contents during WAL replay
  * Ensure an anti-wraparound VACUUM counts a page as scanned when
    it's only verified that no tuples need freezing
  * Fix full-table-vacuum request mechanism for MultiXactIds
  * Fix race condition in GIN index posting tree page deletion
  * Avoid flattening a subquery whose SELECT list contains a
    volatile function wrapped inside a sub-SELECT
  * See release notes for a full list of changes:
    http://www.postgresql.org/docs/9.3/static/release-9-3-2.html
    /usr/share/doc/packages/postgresql93/HISTORY
* Fri Dec  6 2013 kpetsch@suse.com
- Added option to build postgresql-devel package separatly from
  postresql-libs
* Sat Nov 16 2013 darin@darins.net
- Update to version 9.3.1:
  * Update hstore extension with JSON functionality
  * Fix memory leak when creating range indexes
  * Serializable snapshot fixes
  * Fix libpq SSL deadlock bug
  * Fix timeline handling bugs in pg_receivexlog
  * Prevent CREATE FUNCTION from checking SET variables unless
    function body checking is enabled
  * Remove rare inaccurate warning during vacuum of index-less tables
* Wed Sep 11 2013 kpetsch@suse.com
- Added patch to build testsuite package (bnc#829952)
* Wed Sep 11 2013 max@suse.com
- Re-enable running the regression tests during build.
- The test suite needs the timezone package.
* Wed Sep  4 2013 keptsch@suse.com
- Updated to version 9.3:
  * Add materialized views
  * Make simple views auto-updatable
  * Many JSON improvements, including the addition of operators
    and functions to extract values from JSON data strings
  * Implement SQL-standard LATERAL option for FROM-clause
    subqueries and function calls
  * Allow foreign data wrappers to support writes
    (insers/updates/deletes) on foreign tables
  * Add a Postgres foreign data wrapper contrib module
  * Add support for event triggers
  * Add optional ability to checksum data pages and report
    corruption
  * Allow a streaming replication standby to follow a timeline
    switch, and faster failover
  * Dramatically reduce System V shared memory requirements
  * Prevent non-key-field row updates from locking foreign key
    rows
  * Add command-line utility pg_isready
  * Add pg_xlogdump contrib program
  * See release notes for a full list of changes:
    http://www.postgresql.org/docs/9.3/static/release-9-3.html
    /usr/share/doc/packages/postgresql93/HISTORY
* Wed May  8 2013 schwab@suse.de
- postgresql-tas-aarch64.patch: Implement TAS for aarch64
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Tue Apr  2 2013 max@suse.com
- Updated to version 9.2.4 (bnc#812525):
  * CVE-2013-1899: Fix insecure parsing of server command-line
    switches. A connection request containing a database name that
    begins with "-" could be crafted to damage or destroy files
    within the server's data directory, even if the request is
    eventually rejected.
  * CVE-2013-1900: Reset OpenSSL randomness state in each
    postmaster child process. This avoids a scenario wherein
    random numbers generated by "contrib/pgcrypto" functions might
    be relatively easy for another database user to guess. The
    risk is only significant when the postmaster is configured
    with ssl = on but most connections don't use SSL encryption.
  * CVE-2013-1901: Make REPLICATION privilege checks test current
    user not authenticated user.  An unprivileged database user
    could exploit this mistake to call pg_start_backup() or
    pg_stop_backup(), thus possibly interfering with creation of
    routine backups.
  * See the release notes for the rest of the changes:
    http://www.postgresql.org/docs/9.2/static/release-9-2-4.html
    /usr/share/doc/packages/postgresql92/HISTORY
* Wed Feb 13 2013 max@suse.com
- Version 9.2.3 also fixes bnc#802679, CVE-2013-0255.
- Remove postgresql92-full.spec.in and use postgresql92.spec as the
  master for generating postgresql92-libs.spec.
* Fri Feb  8 2013 darin@darins.net
- Updated to version 9.2.3
  * Prevent execution of enum_recv from SQL (Tom Lane)
  * Fix multiple problems in detection of when a consistent database
    state has been reached during WAL replay
  * Fix detection of end-of-backup point when no actual redo
    work is required
  * Update minimum recovery point when truncating a relation file
  * Fix recycling of WAL segments after changing recovery target
    timeline
  * Properly restore timeline history files from archive on
    cascading standby servers
  * Fix lock conflict detection on hot-standby servers
  * Fix missing cancellations in hot standby mode
  * See the release notes for the rest of the changes:
    http://www.postgresql.org/docs/9.2/static/release-9-2-3.html
    /usr/share/doc/packages/postgresql/HISTORY
* Tue Jan  8 2013 max@suse.com
- Use PDX license string.
* Thu Dec 20 2012 max@suse.com
- Conflicts tags don't support the != operator.
* Thu Dec 13 2012 darin@darins.net
- Updated to version 9.2.2
  * Fix multiple bugs associated with
    CREATE/DROP INDEX CONCURRENTLY
  * Correct predicate locking for DROP INDEX CONCURRENTLY
  * Fix buffer locking during WAL replay
  * Fix an error in WAL generation logic for GIN indexes
  * Fix an error in WAL replay logic for SP-GiST indexes
  * Fix incorrect detection of end-of-base-backup location
    during WAL recovery
  * Properly remove startup process's virtual XID lock when
    promoting a hot standby server to normal running
  * Avoid bogus "out-of-sequence timeline ID" errors in standby
    mode
  * Prevent the postmaster from launching new child processes after
    it's received a shutdown signal
  * Fix the syslogger process to not fail when log_rotation_age
    exceeds 2^31 milliseconds
  * Fix WaitLatch() to return promptly when the requested timeout
    expires
  * Avoid corruption of internal hash tables when out of memory
  * Prevent file descriptors for dropped tables from being held
    open past transaction end
  * See the release notes for the rest of the changes:
    http://www.postgresql.org/docs/9.2/static/release-9-2-2.html
    /usr/share/doc/packages/postgresql/HISTORY
* Mon Nov 19 2012 max@suse.com
- Change mechanism for making postgresql??-devel exclusive
  (bnc#789562).
* Fri Oct  5 2012 max@suse.com
- Resolve "have choice for libpq.so.5" by ignoring postgresql-libs.
* Thu Oct  4 2012 max@suse.com
- Get the new packaging scheme over to the postgresql92 packages
  and make 9.2 the new default version.
* Mon Oct  1 2012 max@suse.com
- Bugfix release 9.1.6 (bnc#782251) to fix data corruption issues.
  * Users who upgrade from a previous 9.1 release should run
    REINDEX after applying this update.
    See also: http://wiki.postgresql.org/wiki/20120924updaterelease
  * For the full list of changes, see
    http://www.postgresql.org/docs/9.1/static/release.html
- Change the base name of all PostgreSQL packages from postgresql
  to postgresql91 and adopt the new packaging schema, which allows
  the parallel installation of multiple PostgreSQL versions to
  simplify and speedup migration.
- Move init script, sysconfig file and firewall configuration into
  a new package called postgresql-init which can work with
  different PostgreSQL versions.
* Mon Sep 17 2012 zawel1@gmail.com
- Security and bugfix release 9.1.5:
  * Ignore SECURITY DEFINER and SET attributes for a procedural
    language's call handler (CVE-2012-2655)
  * Fix incorrect password transformation in "contrib/pgcrypto"'s DES
    crypt() function (CVE-2012-2143)
  * Prevent access to external files/URLs via "contrib/xml2"'s
    xslt_process() (CVE-2012-3488)
  * Prevent access to external files/URLs via XML entity references
    (CVE-2012-3489)
  * See the release notes for the rest of the changes:
    http://www.postgresql.org/docs/9.1/static/release.html
    /usr/share/doc/packages/postgresql/HISTORY
* Mon Mar 12 2012 max@suse.com
- Security and bugfix release 9.1.3:
  * Require execute permission on the trigger function for "CREATE
    TRIGGER" (CVE-2012-0866, bnc#749299).
  * Remove arbitrary limitation on length of common name in SSL
    certificates (CVE-2012-0867, bnc#749301).
  * Convert newlines to spaces in names written in pg_dump
    comments (CVE-2012-0868, bnc#749303).
  * See the release notes for the rest of the changes:
    http://www.postgresql.org/docs/9.1/static/release.html
    /usr/share/doc/packages/postgresql/HISTORY
- This also fixes bnc#701489.
* Wed Oct  5 2011 max@suse.com
- New version 9.1.1. For detailed release notes, see:
  http://www.postgresql.org/docs/9.1/static/release-9-1-1.html
- Stop using deprecated silent_mode in default config.
- postgresql-perl514.patch is no longer needed.
- Use %%_smp_mflags for parallel make
- Keep the rpath when linking plperl [bnc#578053].
* Fri Sep 16 2011 jengelh@medozas.de
- Add postgresql-devel to baselibs
* Wed Jun  8 2011 max@novell.com
- Revert the postgresql-libs package split for SLE in preparation
  of submitting the package to SLE11-SP1.
* Wed May 25 2011 max@novell.com
- Fix file name of last added patch and remove overlong comment.
* Wed May 25 2011 idonmez@novell.com
- Add postgresql-9.0.4-perl514.patch: For Perl 5.14 GvCV(sv) is no
  longer an lvalue and needs to be replaced by GvCV_set(sv, value)
* Thu Apr 21 2011 max@novell.com
- Bugfix release: 9.0.4:
  * This update contains a critical fix to the pg_upgrade utility
    which prevents significant downtime issues. Do not use
    pg_upgrade without installing this update first.
    http://wiki.postgresql.org/wiki/20110408pg_upgrade_fix
  * change SQLSTATE for Hot Standby warnings
  * prevent bgwriter hang during recovery
  * prevent recursive composite type creation
  * disallow dropping tables whose triggers are still pending
  * allow use of "replication" as a user name
  * prevent a crash during GEQO planning
  * improve join plans for tables with missing statistics
  * fix error with SELECT FOR UPDATE in a subselect
  * close PL/python array slice memory leak
  * allow SSL connections for users with no home directory
- http://www.postgresql.org/docs/9.0/static/release-9-0-4.html
* Fri Apr  1 2011 nkrinner@novell.com
- enabled --with-ossp-uuid
* Fri Mar  4 2011 max@novell.com
- Fix the fix of the fix for the successors of postgresql-libs.
* Mon Feb 21 2011 ro@suse.de
- provide postgresql-libs in the specfile that actually builds
  the libs package
* Sat Feb 19 2011 coolo@novell.com
- fix update of libs
* Thu Feb 17 2011 max@novell.com
- Move all of pgxs into the devel package to fix build of server
  extensions.
* Wed Feb 16 2011 max@novell.com
- Move pg_config from -server to -devel to fix build of certain
  client apps and language bindings, but using pg_config on the
  client side is still considered broken, because it tells what
  got linked into the server binary not what got linked into libpq.
* Tue Feb  8 2011 max@novell.com
- Remove unneeded PreReq from postgresql on postgresql-libs.
* Fri Feb  4 2011 max@suse.de
- New version: 9.0.3. For the complete release notes, see
  http://www.postgresql.org/docs/9.0/static/release.html
- Build libs and devel separate from the main package.
- Build the PL subpackages as part of the main package.
- Have separate packages for libpq and libecpg.
- Generate the main and lib spec files from postgresql.spec.in.
* Wed Dec  8 2010 max@novell.com
- Fix LSB conformance of the init script (bnc#658014).
* Thu Oct  7 2010 max@suse.de
- Security and bugfix release 8.4.5 (bnc#643771):
  * Use a separate interpreter for each calling SQL userid in
    PL/Perl and PL/Tcl (CVE-2010-3433).
  * Prevent possible crashes in pg_get_expr() by disallowing it
    from being called with an argument that is not one of the
    system catalog columns it's intended to be used with.
  * Fix incorrect placement of placeholder evaluation.
  * Fix possible duplicate scans of UNION ALL member relations.
  * Fix "cannot handle unplanned sub-select" error.
  * Fix mishandling of whole-row Vars that reference a view or
    sub-select and appear within a nested sub-select.
  * Fix mishandling of cross-type IN comparisons.
  * Fix computation of ANALYZE statistics for tsvector columns.
  * Improve planner's estimate of memory used by array_agg(),
    string_agg(), and similar aggregate functions.
  * Fix failure to mark cached plans as transient.
  * Reduce PANIC to ERROR in some occasionally-reported btree
    failure cases, and provide additional detail in the resulting
    error messages.
  * Fix incorrect search logic for partial-match queries with GIN
    indexes.
  * Prevent show_session_authorization() from crashing within
    autovacuum processes.
  * Defend against functions returning setof record where not all
    the returned rows are actually of the same rowtype.
  * Fix possible corruption of pending trigger event lists during
    subtransaction rollback.
  * Fix possible failure when hashing a pass-by-reference function
    result.
  * Improve merge join's handling of NULLs in the join columns.
  * Take care to fsync the contents of lockfiles (both
    postmaster.pid and the socket lockfile) while writing them.
  * Avoid recursion while assigning XIDs to heavily-nested
    subtransactions.
  * Avoid holding open old WAL segments in the walwriter process.
  * Fix log_line_prefix's %%i escape, which could produce junk
    early in backend startup.
  * Prevent misinterpretation of partially-specified relation
    options for TOAST tables.
  * Fix inheritance count tracking in ALTER TABLE ... ADD
    CONSTRAINT.
  * Fix possible data corruption in ALTER TABLE ... SET TABLESPACE
    when archiving is enabled.
  * Allow CREATE DATABASE and ALTER DATABASE ... SET TABLESPACE to
    be interrupted by query-cancel.
  * Improve CREATE INDEX's checking of whether proposed index
    expressions are immutable.
  * Fix REASSIGN OWNED to handle operator classes and families.
  * Fix possible core dump when comparing two empty tsquery values.
  * Fix LIKE's handling of patterns containing %% followed by _
  * Re-allow input of Julian dates prior to 0001-01-01 AD.
  * Fix PL/pgSQL to throw an error, not crash, if a cursor is
    closed within a FOR loop that is iterating over that cursor.
  * In PL/Python, defend against null pointer results from
    PyCObject_AsVoidPtr and PyCObject_FromVoidPtr
  * In libpq, fix full SSL certificate verification for the case
    where both host and hostaddr are specified.
  * Make psql recognize DISCARD ALL as a command that should not
    be encased in a transaction block in autocommit-off mode.
  * Fix some issues in pg_dump's handling of SQL/MED objects.
  * Improve pg_dump and pg_restore's handling of non-seekable
    archive files. This is important for proper functioning of
    parallel restore.
  * Improve parallel pg_restore's ability to cope with selective
    restore (-L option).
  * Fix ecpg to process data from RETURNING clauses correctly.
  * Fix some memory leaks in ecpg.
  * Improve contrib/dblink's handling of tables containing dropped
    columns.
  * Fix connection leak after "duplicate connection name" errors
    in contrib/dblink.
  * Fix contrib/dblink to handle connection names longer than 62
    bytes correctly.
  * Add hstore(text, text) function to contrib/hstore.
* Thu May 27 2010 max@suse.de
- Security and bugfix release 8.4.4:
  * Enforce restrictions in plperl using an opmask applied to the
    whole interpreter, instead of using Safe.pm. Recent
    developments have convinced us that Safe.pm is too insecure to
    rely on for making plperl trustable. This change removes use of
    Safe.pm altogether, in favor of using a separate interpreter
    with an opcode mask that is always applied. Pleasant side
    effects of the change include that it is now possible to use
    Perl's strict pragma in a natural way in plperl, and that
    Perl's $a and $b variables work as expected in sort routines,
    and that function compilation is significantly
    faster. (CVE-2010-1169)
  * Prevent PL/Tcl from executing untrustworthy code from
    pltcl_modules.  PL/Tcl's feature for autoloading Tcl code from
    a database table could be exploited for trojan-horse attacks,
    because there was no restriction on who could create or insert
    into that table. This change disables the feature unless
    pltcl_modules is owned by a superuser. (However, the
    permissions on the table are not checked, so installations that
    really need a less-than-secure modules table can still grant
    suitable privileges to trusted non-superusers.) Also, prevent
    loading code into the unrestricted "normal" Tcl interpreter
    unless we are really going to execute a pltclu
    function. (CVE-2010-1170)
  * Fix data corruption during WAL replay of ALTER ... SET
    TABLESPACE.  When archive_mode is on, ALTER ... SET TABLESPACE
    generates a WAL record whose replay logic was incorrect. It
    could write the data to the wrong place, leading to
    possibly-unrecoverable data corruption. Data corruption would
    be observed on standby slaves, and could occur on the master as
    well if a database crash and recovery occurred after committing
    the ALTER and before the next checkpoint.
  * Fix possible crash if a cache reset message is received during
    rebuild of a relcache entry. This error was introduced in 8.4.3
    while fixing a related failure.
  * Apply per-function GUC settings while running the language
    validator for the function.
  * This avoids failures if the function's code is invalid without
    the setting; an example is that SQL functions may not parse if
    the search_path is not correct.
  * Do constraint exclusion for inherited UPDATE and DELETE target
    tables when constraint_exclusion = partition. Due to an
    oversight, this setting previously only caused constraint
    exclusion to be checked in SELECT commands.
  * Do not allow an unprivileged user to reset superuser-only
    parameter settings.  Previously, if an unprivileged user ran
    ALTER USER ... RESET ALL for himself, or ALTER DATABASE
    ... RESET ALL for a database he owns, this would remove all
    special parameter settings for the user or database, even ones
    that are only supposed to be changeable by a superuser. Now,
    the ALTER will only remove the parameters that the user has
    permission to change.
  * Avoid possible crash during backend shutdown if shutdown occurs
    when a CONTEXT addition would be made to log entries.  In some
    cases the context-printing function would fail because the
    current transaction had already been rolled back when it came
    time to print a log message.
  * Fix erroneous handling of %%r parameter in recovery_end_command.
    The value always came out zero.
  * Ensure the archiver process responds to changes in
    archive_command as soon as possible.
  * Fix pl/pgsql's CASE statement to not fail when the case
    expression is a query that returns no rows.
  * Update pl/perl's ppport.h for modern Perl versions.
  * Fix assorted memory leaks in pl/python.
  * Handle empty-string connect parameters properly in ecpg.
  * Prevent infinite recursion in psql when expanding a variable
    that refers to itself.
  * Fix psql's \copy to not add spaces around a dot within \copy
    (select ...). Addition of spaces around the decimal point in a
    numeric literal would result in a syntax error.
  * Avoid formatting failure in psql when running in a locale
    context that doesn't match the client_encoding.
  * Fix unnecessary "GIN indexes do not support whole-index scans"
    errors for unsatisfiable queries using contrib/intarray
    operators.
  * Ensure that contrib/pgstattuple functions respond to cancel
    interrupts promptly.
  * Make server startup deal properly with the case that shmget()
    returns EINVAL for an existing shared memory segment.
    This behavior has been observed on BSD-derived kernels
    including OS X. It resulted in an entirely-misleading startup
    failure complaining that the shared memory request size was too
    large.
* Thu Apr 29 2010 max@suse.de
- Use %%configure to pick up the default directories (bnc#600616).
* Tue Mar 16 2010 max@suse.de
- Security and bugfix release 8.4.3.
* Thu Mar 11 2010 max@suse.de
- Disable GSSAPI, XML, kerberos and make check in OBS for SLES9.
* Thu Mar 11 2010 max@suse.de
- Fix build for SLES9
* Tue Feb  9 2010 max@suse.de
- Fix package descriptions.
* Wed Dec 16 2009 max@suse.de
- Security and bugfix release 8.4.2:
  * CVE-2009-4136: Protect against indirect security threats
    caused by index functions changing session-local state. This
    change prevents allegedly-immutable index functions from
    possibly subverting a superuser's session.
  * CVE-2009-4034: Reject SSL certificates containing an embedded
    null byte in the common name (CN) field. This prevents
    unintended matching of a certificate to a server or client
    name during SSL validation.
  * Fix hash index corruption. The 8.4 change that made hash
    indexes keep entries sorted by hash value failed to update the
    bucket splitting and compaction routines to preserve the
    ordering. So application of either of those operations could
    lead to permanent corruption of an index, in the sense that
    searches might fail to find entries that are present. To deal
    with this, it is recommended to REINDEX any hash indexes you
    may have after installing this update.
  * Fix possible crash during backend-startup-time cache
  initialization
  * Avoid crash on empty thesaurus dictionary
  * Prevent signals from interrupting VACUUM at unsafe times. This
  fix prevents a PANIC if a VACUUM FULL is cancelled after it's
  already committed its tuple movements, as well as transient
  errors if a plain VACUUM is interrupted after having truncated
  the table.
  * Fix possible crash due to integer overflow in hash table size
  calculation. This could occur with extremely large planner
  estimates for the size of a hashjoin's result.
  * Fix crash if a DROP is attempted on an internally-dependent
  object.
  * Fix very rare crash in inet/cidr comparisons.
  * Ensure that shared tuple-level locks held by prepared
  transactions are not ignored.
  * Fix premature drop of temporary files used for a cursor that is
  accessed within a subtransaction.
  * Fix memory leak in syslogger process when rotating to a new CSV
  logfile.
  * Fix memory leak in postmaster when re-parsing "pg_hba.conf".
  * Make FOR UPDATE/SHARE in the primary query not propagate into
  WITH queries.
  * Fix bug with a WITH RECURSIVE query immediately inside another
  one.
  * Fix concurrency bug in hash indexes. Concurrent insertions
  could cause index scans to transiently report wrong results.
  * Fix incorrect logic for GiST index page splits, when the split
  depends on a non-first column of the index.
  * Fix wrong search results for a multi-column GIN index with
  fastupdate enabled.
  * Fix bugs in WAL entry creation for GIN indexes. These bugs were
  masked when full_page_writes was on, but with it off a WAL
  replay failure was certain if a crash occurred before the next
  checkpoint.
  * Don't error out if recycling or removing an old WAL file fails
  at the end of checkpoint. It's better to treat the problem as
  non-fatal and allow the checkpoint to complete. Future
  checkpoints will retry the removal. Such problems are not
  expected in normal operation, but have been seen to be caused
  by misdesigned Windows anti-virus and backup software.
  * Ensure WAL files aren't repeatedly archived on Windows. This is
  another symptom that could happen if some other process
  interfered with deletion of a no-longer-needed file.
  * Fix PAM password processing to be more robust.  The previous
  code is known to fail with the combination of the Linux
  pam_krb5 PAM module with Microsoft Active Directory as the
  domain controller. It might have problems elsewhere too, since
  it was making unjustified assumptions about what arguments the
  PAM stack would pass to it.
  * Raise the maximum authentication token (Kerberos ticket) size
  in GSSAPI and SSPI authentication methods.  While the old
  2000-byte limit was more than enough for Unix Kerberos
  implementations, tickets issued by Windows Domain Controllers
  can be much larger.
  * Ensure that domain constraints are enforced in constructs like
  ARRAY[...]::domain, where the domain is over an array type.
  * Fix foreign-key logic for some cases involving composite-type
  columns as foreign keys.
  * Ensure that a cursor's snapshot is not modified after it is
  created. This could lead to a cursor delivering wrong results
  if later operations in the same transaction modify the data the
  cursor is supposed to return.
  * Fix CREATE TABLE to properly merge default expressions coming
  from different inheritance parent tables. This used to work but
  was broken in 8.4.
  * Re-enable collection of access statistics for sequences. This
  used to work but was broken in 8.3.
  * Fix processing of ownership dependencies during CREATE OR REPLACE
  FUNCTION.
  * Fix incorrect handling of WHERE "x"="x" conditions.  In some cases
  these could get ignored as redundant, but they aren't -- they're
  equivalent to "x" IS NOT NULL.
  * Fix incorrect plan construction when using hash aggregation to
  implement DISTINCT for textually identical volatile
  expressions.
  * Fix Assert failure for a volatile SELECT DISTINCT ON expression.
  * Fix ts_stat() to not fail on an empty tsvector value.
  * Make text search parser accept underscores in XML attributes.
  * Fix encoding handling in xml binary input. If the XML header
  doesn't specify an encoding, we now assume UTF-8 by default;
  the previous handling was inconsistent.
  * Fix bug with calling plperl from plperlu or vice versa. An
  error exit from the inner function could result in crashes due
  to failure to re-select the correct Perl interpreter for the
  outer function.
  * Fix session-lifespan memory leak when a PL/Perl function is
  redefined.
  * Ensure that Perl arrays are properly converted to PostgreSQL
  arrays when returned by a set-returning PL/Perl function. This
  worked correctly already for non-set-returning functions.
  * Fix rare crash in exception processing in PL/Python.
  * Fix ecpg problem with comments in DECLARE CURSOR statements.
  * Fix ecpg to not treat recently-added keywords as reserved
  words.  This affected the keywords CALLED, CATALOG, DEFINER,
  ENUM, FOLLOWING, INVOKER, OPTIONS, PARTITION, PRECEDING, RANGE,
  SECURITY, SERVER, UNBOUNDED, and WRAPPER.
  * Re-allow regular expression special characters in psql's \df
  function name parameter.
  * In "contrib/pg_standby", disable triggering failover with a
  signal on Windows. This never did anything useful, because
  Windows doesn't have Unix-style signals, but recent changes
  made it actually crash.
  * Put FREEZE and VERBOSE options in the right order in the VACUUM
  command that "contrib/vacuumdb" produces.
  * Fix possible leak of connections when "contrib/dblink"
  encounters an error.
  * Ensure psql's flex module is compiled with the correct system
  header definitions.  This fixes build failures on platforms
  where --enable-largefile causes incompatible changes in the
  generated code.
  * Make the postmaster ignore any application_name parameter in
  connection request packets, to improve compatibility with
  future libpq versions.
  * Update the timezone abbreviation files to match current reality
  This includes adding IDT to the default timezone abbreviation
  set.
* Wed Dec 16 2009 jengelh@medozas.de
- package documentation as noarch
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Wed Sep 16 2009 crrodriguez@novell.com
- use find_lang to package language files correctly
* Thu Sep 10 2009 max@suse.de
- Security and bugfix release 8.4.1:
  * Fix WAL page header initialization at the end of archive
    recovery. This could lead to failure to process the WAL in a
    subsequent archive recovery.
  * Fix "cannot make new WAL entries during recovery" error.
  * Fix problem that could make expired rows visible after a crash.
    This bug involved a page status bit potentially not being set
    correctly after a server crash.
  * Disallow RESET ROLE and RESET SESSION AUTHORIZATION inside
    security-definer functions. This covers a case that was missed
    in the previous patch that disallowed SET ROLE and SET SESSION
    AUTHORIZATION inside security-definer functions.
    (See CVE-2007-6600)
  * Make LOAD of an already-loaded loadable module into a no-op.
  * Formerly, LOAD would attempt to unload and re-load the module,
    but this is unsafe and not all that useful.
  * Make window function PARTITION BY and ORDER BY items always be
    interpreted as simple expressions. In 8.4.0 these lists were
    parsed following the rules used for top-level GROUP BY and
    ORDER BY lists. But this was not correct per the SQL standard,
    and it led to possible circularity.
  * Fix several errors in planning of semi-joins.  These led to
    wrong query results in some cases where IN or EXISTS was used
    together with another join.
  * Fix handling of whole-row references to subqueries that are
    within an outer join. An example is SELECT COUNT(ss.*) FROM
    ... LEFT JOIN (SELECT ...) ss ON .... Here, ss.* would be
    treated as ROW(NULL,NULL,...) for null-extended join rows,
    which is not the same as a simple NULL. Now it is treated as a
    simple NULL.
  * Fix Windows shared-memory allocation code.  This bug led to the
    often-reported "could not reattach to shared memory" error
    message.
  * Fix locale handling with plperl.
    This bug could cause the server's locale setting to change when
    a plperl function is called, leading to data corruption.
  * Fix handling of reloptions to ensure setting one option doesn't
    force default values for others.
  * Ensure that a "fast shutdown" request will forcibly terminate
    open sessions, even if a "smart shutdown" was already in
    progress.
  * Avoid memory leak for array_agg() in GROUP BY queries.
  * Treat to_char(..., 'TH') as an uppercase ordinal suffix with
  'HH'/'HH12'. It was previously handled as 'th' (lowercase).
  * Include the fractional part in the result of EXTRACT(second)
    and EXTRACT(milliseconds) for time and time with time zone
    inputs.
    This has always worked for floating-point datetime
    configurations, but was broken in the integer datetime code.
  * Fix overflow for INTERVAL 'x ms' when x is more than 2 million
    and integer datetimes are in use.
  * Improve performance when processing toasted values in index
    scans. This is particularly useful for PostGIS.
  * Fix a typo that disabled commit_delay.
  * Output early-startup messages to postmaster.log if the server
    is started in silent mode.  Previously such error messages were
    discarded, leading to difficulty in debugging.
  * Remove translated FAQs. They are now on the wiki. The main FAQ
    was moved to the wiki some time ago.
  * Fix pg_ctl to not go into an infinite loop if postgresql.conf
    is empty.
  * Fix several errors in pg_dump's --binary-upgrade mode.
  * pg_dump --binary-upgrade is used by pg_migrator.
  * Fix contrib/xml2's xslt_process() to properly handle the
    maximum number of parameters (twenty).
  * Improve robustness of libpq's code to recover from errors
    during COPY FROM STDIN.
  * Avoid including conflicting readline and editline header files
    when both libraries are installed.
  * Work around gcc bug that causes "floating-point exception"
    instead of "division by zero" on some platforms.
* Mon Jul 27 2009 poeml@suse.de
- postgresql-8.4.0-sle10-timestamptz.patch added, and applied
  _only_ on SLE10. It fixes a build failure due to a test case that
  seems to be confused by daylight saving time in the time zone
  that the test expects its result (PDT vs. PST). Since this
  failure happened only on SLE10, I assume that the test case isn't
  broken, and some peculiarity on that (rather old now) platform is
  to blame (possibly too old timezone files). Also, the testcase is
  checking correctness when converting timezones > 32 bit, which
  actually seems to work.
* Wed Jul 15 2009 poeml@suse.de
- replace "ident sameuser" with "ident" as auth method for the
  initdb call in the init script, because the former doesn't work
  with PostgreSQL 8.4. With the generated pg_hba.conf, PostgreSQL
  failed to start. Added note to the upgrade READMEs. [bnc#522375]
* Tue Jul  7 2009 max@suse.de
- New major release: 8.4.0
- Improvements include:
  * Windowing Functions
  * Common Table Expressions and Recursive Queries
  * Default and variadic parameters for functions
  * Parallel Restore
  * Column Permissions
  * Per-database locale settings
  * Improved hash indexes
  * Improved join performance for EXISTS and NOT EXISTS queries
  * Easier-to-use Warm Standby
  * Automatic sizing of the Free Space Map
  * Visibility Map (greatly reduces vacuum overhead for
    slowly-changing tables)
  * Version-aware psql (backslash commands work against older
    servers)
  * Support SSL certificates for user authentication
  * Per-function runtime statistics
  * Easy editing of functions in psql
  * New contrib modules: pg_stat_statements, auto_explain, citext,
    btree_gin
* Wed May  6 2009 max@suse.de
- Remove dependency on local posixrules from horology test.
* Mon Mar 23 2009 max@suse.de
- Security release 8.3.7
  * Fixes a vulnerability that allowed remote authenticated
    users to cause a denial of service (stack consumption)
    via mismatched encoding conversion requests.
  * Details of the other bugfixes contained in this and
    previous releases can be found here:
    http://www.postgresql.org/docs/8.3/static/release.html
    /usr/share/doc/packages/postgresql/HISTORY
- Users of GiST indexes should "REINDEX" them after installing
  this update.
- Re-added libpgport.a to the devel package, as some apps require
  it, although it is meant to be internal to the PostgreSQL
  backend.
- Fix removal of leftover files on database startup (bnc#473644).
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed Nov  5 2008 max@suse.de
- Bugfix release: 8.3.5
  * Fix GiST index corruption due to marking the wrong index
    entry "dead" after a deletion. This would result in index
    searches failing to find rows they should have found.
  * Fix backend crash when the client encoding cannot represent a
    localized error message.
  * Fix possible crash in bytea-to-XML mapping.
  * Fix possible crash when deeply nested functions are invoked
    from a trigger.
  * Improve optimization of "expression" IN ("expression-list")
    queries.
  * Fix mis-expansion of rule queries when a sub-SELECT appears
    in a function call in FROM, a multi-row VALUES list, or a
    RETURNING list.
  * Fix Assert failure during rescan of an IS NULL search of
    a GiST index.
  * Fix memory leak during rescan of a hashed aggregation plan.
  * Ensure an error is reported when a newly-defined PL/pgSQL
    trigger function is invoked as a normal function.
  * Force a checkpoint before "CREATE DATABASE" starts to copy
    files This prevents a possible failure if files had recently
    been deleted in the source database.
  * Prevent possible collision of relfilenode numbers when moving
    a table to another tablespace with "ALTER SET TABLESPACE".
  * Fix incorrect text search headline generation when single
    query item matches first word of text.
  * Fix improper display of fractional seconds in interval
    values when using a non-ISO datestyle in an
    "--enable-integer-datetimes" build.
  * Make ILIKE compare characters case-insensitively even when
    they're escaped.
  * Ensure "DISCARD" is handled properly by statement logging.
  * Fix incorrect logging of last-completed-transaction time
    during PITR recovery.
  * Ensure SPI_getvalue and SPI_getbinval behave correctly when
    the passed tuple and tuple descriptor have different numbers
    of columns.
  * Fix small memory leak when using libpq's gsslib parameter.
  * Ensure libgssapi is linked into libpq if needed.
  * Fix ecpg's parsing of "CREATE ROLE".
  * Fix recent breakage of pg_ctl restart.
* Thu Sep 25 2008 max@suse.de
- Bugfix release: 8.3.4
- Issues fixed include autovacuum crashes reported by several
  users, two Heap Only Tuple bugs, a foreign key failure
  condition, a too-small lock address space, two Write Ahead Log
  bugs, several planner mistakes, and numerous "corner condition"
  bugs.
* Fri Sep  5 2008 max@suse.de
- New version: 8.3.3 with countless bug fixes over 8.3.1.
- For details, see
  http://www.postgresql.org/docs/8.3/static/release-8-3-2.html ,
  http://www.postgresql.org/docs/8.3/static/release-8-3-3.html ,
  or /usr/share/doc/packages/postgresql/HISTORY .
* Thu Aug 28 2008 cthiel@suse.de
- fix init script
* Mon May 19 2008 schwab@suse.de
- Fix broken configure check.
* Fri May  9 2008 aj@suse.de
- Add baselibs.conf.
* Fri Apr 18 2008 max@suse.de
- Removed static libs from postgresql-devel.
- Removed more old Obsoletes: tags.
- Fixed path to pid file in init script.
- Moved "make check" to %%check section
- Silence some bogus rpmlint warnings
* Thu Apr 10 2008 max@suse.de
- Adopt the 8.3.1 package from Peter Eisentraut's OBS project.
- New features in PostgreSQL 8.3 include:
  * Full text search is integrated into the core database system
  * Support for the SQL/XML standard, including new operators and
    an XML data type
  * Enumerated data types (ENUM)
  * Arrays of composite types
  * Universally Unique Identifier (UUID) data type
  * Add control over whether NULLs sort first or last
  * Updatable cursors
  * Server configuration parameters can now be set on a
    per-function basis
  * User-defined types can now have type modifiers
  * Automatically re-plan cached queries when table definitions
    change or statistics are updated
  * Numerous improvements in logging and statistics collection
  * Support multiple concurrent autovacuum processes, and other
    autovacuum improvements
- Remove old provides/obsoletes tags for way-back package renames.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Jan 10 2008 max@suse.de
- Update to 8.2.6 to fix five security issues:
  - Index Functions Privilege Escalation: CVE-2007-6600
  - Regular Expression Denial-of-Service: CVE-2007-4772,
    CVE-2007-6067, CVE-2007-4769, #329282
  - DBLink Privilege Escalation: CVE-2007-6601, #328403
* Wed Jun  6 2007 max@suse.de
- New version: 8.2.4
- The list of changes between the 8.1 and 8.2 series is too long
  to reproduce here. It can be found under
  /usr/share/doc/packages/postgresql/HISTORY when the postgresql
  package is installed or online at http://www.postgresql.org.
- Splited the postgresql-pl package into individual packages for
  PL/Perl, PL/Python and PL/Tcl.
- Added a config file for SuSEfirewall2 (#247370).
* Thu Mar 29 2007 rguenther@suse.de
- Add bison, flex and zlib-devel BuildRequires.
* Tue Oct 17 2006 max@suse.de
- New patchlevel release: 8.1.5
- Disallow aggregate functions in "UPDATE" commands, except within
  sub-SELECTs. The behavior of such an aggregate was unpredictable,
  and in 8.1.X could cause a crash, so it has been disabled.
- Fix core dump when an untyped literal is taken as ANYARRAY.
- Fix core dump in duration logging for extended query protocol when
  a "COMMIT" or "ROLLBACK" is executed.
- Fix mishandling of AFTER triggers when query contains a SQL function
  returning multiple rows.
- Fix "ALTER TABLE ... TYPE" to recheck NOT NULL for USING clause.
- Fix string_to_array() to handle overlapping matches for the
  separator string.
- Fix to_timestamp() for AM/PM formats.
- Fix autovacuum's calculation that decides whether "ANALYZE" is
  needed.
- Fix corner cases in pattern matching for psql's \d commands.
- Fix index-corrupting bugs in /contrib/ltree.
- Numerous robustness fixes in ecpg.
- Fix backslash escaping in /contrib/dbmirror.
- Minor fixes in /contrib/dblink and /contrib/tsearch2.
- Efficiency improvements in hash tables and bitmap index scans.
* Wed May 24 2006 max@suse.de
- Update to 8.1.4 to fix SQL injection vulnerabilities
  (bug #177931, CVE-2006-2313, CVE-2006-2314).
- Added a new postgresql-SECURITY-NOTICE file with an FAQ that
  explains the issues.
* Mon Feb 13 2006 max@suse.de
- New version: 8.1.3 (#150376).
- Relaxed dependencies between subpackages to simplify future
  updates.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 max@suse.de
- Moved from logrotate to PostgreSQL's own log rotation facility.
- Log files are now located under /var/lib/pgsql/data/pg_log .
- Improved error reporting on test suite failures.
* Thu Dec 22 2005 max@suse.de
- New version: 8.1.1
* Fri Jun 17 2005 max@suse.de
- Removed bogus %%patch3
* Thu Jun  2 2005 max@suse.de
- Added postgresql-CAN-2005-1409-1410-fix.sh for fixing existing
  installations, and referred to it in the SECURITY-NOTICE.
* Tue May 17 2005 max@suse.de
- Added postgresql-SECURITY-NOTICE to describe the manual actions
  that are needed to apply the bugfixes from 8.0.3 to existing
  installations.
* Tue May 10 2005 max@suse.de
- New patch release: 8.0.3
- Fixes bug #82869, CAN-2005-1410, and CAN-2005-1409
- Obsoletes postgresql-CAN-2005-0247.patch
* Mon Apr 11 2005 max@suse.de
- New patch release: 8.0.2
* Mon Apr  4 2005 uli@suse.de
- hardwire thread safety to yes (test may hang QEMU)
* Fri Apr  1 2005 uli@suse.de
- ignore regressions on ARM
* Wed Mar 16 2005 max@suse.de
- Prevent the wrapper libs from ending up in the provides list.
* Mon Mar 14 2005 max@suse.de
- Added postgresql-CAN-2005-0247.patch to fix bug #65692.
* Fri Mar 11 2005 max@suse.de
- Added some wrapper libs so that old postmaster binaries, back
  to at least 8.1/SLES8 can still be started.
- Extended the init script to use the wrapper libs when needed.
- Setting a senseful umask when creating the postmaster backups
  in %%pre.
* Mon Feb  7 2005 max@suse.de
- New patch release: 8.0.1
- Fixes a vulnerability in the LOAD command.
* Wed Jan 19 2005 max@suse.de
- Update to the final 8.0.0 release.
* Wed Dec 22 2004 max@suse.de
- New version: 8.0.0rc2
* Fri Dec 10 2004 max@suse.de
- New version: 8.0.0rc1
- Recoded README.SuSE.de to UTF-8.
* Fri Dec  3 2004 max@suse.de
- New version: 8.0.0beta5
* Thu Nov 18 2004 ro@suse.de
- use kerberos-devel-packages
* Mon Sep  6 2004 max@suse.de
- Created a separate spec file for the postgresql-pl subpackage.
* Fri Aug 20 2004 max@suse.de
- New version: 7.4.5.
* Thu Jul 15 2004 max@suse.de
- New version: 7.4.3.
* Mon May 24 2004 max@suse.de
- Changed dependency of -devel from the main package to -libs
  (Bug #40922).
* Mon Apr  5 2004 max@suse.de
- Added postgresql-regression.patch to prevent test failures
  during summertime/wintertime changes.
* Thu Mar 11 2004 max@suse.de
- New patch release: 7.4.2
* Fri Jan 16 2004 kukuk@suse.de
- Add pam-devel to neededforbuild
* Mon Jan 12 2004 max@suse.de
- New version: 7.4.1
- Write timestamps to /var/log/postgresql by default.
* Thu Dec 18 2003 max@suse.de
- Package the backend headers as well (make install-all-headers),
  because they are needed for server-side modules written in C.
* Tue Nov 18 2003 max@suse.de
- Install pg_config_manual.h and port.h, because they are needed
  by c.h (postgresql-include.patch).
* Mon Nov 17 2003 max@suse.de
- New version: 7.4. For details see
  http://www.postgresql.org/docs/7.4/static/release.html, or
  /usr/share/doc/packages/postgresql/html/release.html
- Overhauled and simplified the spec file.
- Building with Kerberos-Support.
- Building thread-safe client libraries.
- Architecture-dependent tweaks for the testsuite are not needed
  anymore.
- Better detection for embedded Python build options.
* Mon Oct 20 2003 schwab@suse.de
- Fix last change.
* Sat Oct 18 2003 adrian@suse.de
- ignore minor mis-calculation on mips
- build as user
* Tue Sep 23 2003 max@suse.de
- Fixed version detection in the pre script of the server package.
  (#31570)
- Ignore errors from stop_on_removal (#31607).
* Mon Sep 15 2003 max@suse.de
- Activated the patch, that fixes dbf2pg (#27427). The patch was
  added to the package before, but accidentally didn't get applied.
- Improved handling of old versions of the backend (#27114).
- Stopping the server before uninstallation and restarting it
  after update (#29038).
* Fri Aug 29 2003 mcihar@suse.cz
- python bindings require same python version as it was built with
* Thu Aug 14 2003 max@suse.de
- Added ServiceRestart to sysconfig template.
* Thu Aug 14 2003 ro@suse.de
- fixed chown usage in init-script
* Mon Aug  4 2003 max@suse.de
- New version: 7.3.4.
- Adopted postgresql-multilib.patch from the official PostgreSQL
  RPMs. This obsoletes postgresql-lib64.patch.
- Use test-and-set locks for x86_64 instead of slow semaphores.
  (postgresql-x86_64.patch, Bug #27308)
- make use of %%jobs for parallel builds.
- Fix ownership of /etc/logrotate.d/postgresql (Bug #28431).
- Changed the default locale for the server to "C" to avoid a hard
  dependency to glibc-locale (bug #28338).
- Enabled charset conversion for dbf2pg (Bug #27427).
* Wed Jul 16 2003 meissner@suse.de
- fix hanging builds by another rework of the ppc64
  locking. Apparently we need to do exact stcwx. ; bne ; isync
  sequences to stay correct.
* Tue Jun 24 2003 meissner@suse.de
- Fixed the ppc/ppc64 locking, isync was at the wrong
  position. Replaced full sync by lwsync. slock_ts can
  be 32bit on ppc64 too, we just use lwarx/stwcx which
  handle 32bit components.
* Tue Jun  3 2003 max@suse.de
- New version: 7.3.3.
- Remove unpackaged files.
- pg_hba.conf: only allow local connections from the same user
  by default.
* Fri Mar 14 2003 max@suse.de
- Fixed generation of sql files in contrib, and really install the
  contrib stuff instead of just copying over the source tree
  (Bug #25323, postgresql-contrib.patch).
- Fixed the file-list of the server package.
* Wed Mar 12 2003 max@suse.de
- Fixed a typo in the init script (Bug #25115).
* Thu Mar  6 2003 max@suse.de
- Add support for LSB compatible exit codes for start and stop
  to pg_ctl (postgresql-lsb.patch).
- Use pg_ctl instead of startproc/killproc in init script, because
  it waits until the server is completely fired up or shut down.
  (Bug #24395)
- Removed the libpq.so.2.0 link from the package, because it got
  removed by ldconfig after installation anyways (Bug #24557).
* Tue Feb 25 2003 max@suse.de
- Mark manpages as documentation.
- Create the backup directory during install.
* Mon Feb 24 2003 max@suse.de
- Make a backup of the server binaries during update, and use the
  old server as long as the data files are still in the old format.
* Thu Feb  6 2003 max@suse.de
- New patch release 7.3.2 which fixes several serious bugs.
  See HISTORY for details.
* Tue Jan 28 2003 max@suse.de
- Added metadata for the sysconfig editor.
* Mon Jan 20 2003 max@suse.de
- New version: 7.3.1
- Removed old update scripts, because they don't work anymore.
* Thu Jan 16 2003 bg@suse.de
- Changed the expected test results for hppa to the correct files
* Fri Nov 29 2002 max@suse.de
- New version 7.3.
- Compiling with PAM support.
- Client libraries (perl, tcl, odbc, pgeasy, pq++) have been
  taken out of the PostgreSQL core distribution and will be
  built as separate packages in the future.
- The plperl subpackage has been renamed to pl, and now contains
  PL/Perl, PL/Python, and PL/Tcl.
* Fri Sep 13 2002 max@suse.de
- Added circle_poly-overrun.patch to fix a couple of
  buffer overruns.
* Thu Sep 12 2002 max@suse.de
- Corrected symlink /usr/lib/libpq.so.2.0 [#19490].
- Fixed ownership of /var/lib/pgsql [#19523].
* Fri Sep  6 2002 max@suse.de
- Recovered time stamps of source files and patches.
* Mon Sep  2 2002 max@suse.de
- Updated to patch release 7.2.2 which fixes some security holes.
- Essential diff between 7.2.1 and 7.2.2 is included.
* Tue Aug 20 2002 mmj@suse.de
- Correct PreReq
* Mon Aug 19 2002 kukuk@suse.de
- Fix requires egenix-mx-base -> python-egenix-mx-base
* Thu Aug 15 2002 ro@suse.de
- don't chmod 644 to directories
* Wed Aug 14 2002 ro@suse.de
- added "missingok" to logrotate config
* Fri Aug  9 2002 max@suse.de
- Removed sysconfig from neededforbuild.
- Using x-devel-packages instead of xf86.
* Thu Aug  8 2002 max@suse.de
- Removed support for older SuSE versions.
- Moved log file cration from %%post to rcpostgresql.
- Changed group for /etc/logrotate.d/postgresql.
* Mon Aug  5 2002 max@suse.de
- Enabled the plperl subpackage.
* Tue Jul 30 2002 max@suse.de
- Fixed regression tests for ppc64.
* Fri Jul 12 2002 max@suse.de
- Re-enabled the regression tests.
- Running test suite as nobody.
- Adjusted ppc and lib64 patch to the scheme of the other
  platform patches.
- Better test-and-set assembler code for s390 and s390x.
- Creating postgres user and group during RPM installation.
* Tue Jun 18 2002 meissner@suse.de
- use the powerpc assembler tas() for ppc64 too with adjusted assembler
  names.
* Fri May 24 2002 max@suse.de
- New minor release: 7.2.1
- Temporaryly disabled the regression tests due to changes to
  mktime() that caused some tests to fail.
* Fri May 24 2002 ke@suse.de
- postgresql-python requires egenix-mx-base (DateTime) [# 14745].
* Wed May 22 2002 meissner@suse.de
- %%_lib fixes for lib64 architectures. Now fails at the same point as i386.
* Wed Mar 20 2002 max@suse.de
- Changed postgresql package to PreReq postgresql-libs instead of
  postgresql-lib which is obsolete.
* Fri Mar  8 2002 poeml@suse.de
- add missing / before %%_lib, fixing the preinstall script of -libs
  subpackage
* Wed Mar  6 2002 max@suse.de
- Fixed test-and-set assembler code for s390x.
- Made finding of perl and python site-paths more portable.
- Fixed detection of SuSE dist for older releases.
- Some more %%_libdir corrections.
- Using -fPIC for building shared libs on all architectures.
- Leaving out tk and python subpackages if tk and python
  are not OK.
* Mon Mar  4 2002 max@suse.de
- Fixed creation of pkgIndex.tcl
- Removed some python stuff from the spec file that is now part of
  PostgreSQL's build system.
- Removed unneeded executable permissions from a couple of files.
* Wed Feb 13 2002 max@suse.de
- added support for logrotate
- changed sysconfig stuff and init script to run on both
  schemes (<=7.3 and >=8.0).
* Tue Feb  5 2002 max@suse.de
- Updated to 7.2 final.
- See the file /usr/share/doc/packages/postgresql/HISTORY
  for changes and incompatibilities since version 7.1.x.
- Adapted the init script to match the new versions of killproc
  and PostgreSQL.
* Mon Jan 28 2002 max@suse.de
- Updated to 7.2rc2
- Removed temporary header fix.
- Added a patch for autoconf-2.52 (disabled by derfault).
- Added english version of README.SuSE
* Tue Jan 22 2002 max@suse.de
- removed os.h. It's not needed anymore.
- fixed locations of internal header files (temporary).
- postgresql-python now obsoletes pygresql.
- updated the files lists.
* Mon Jan 21 2002 max@suse.de
- New version 7.2b5
* Tue Dec 18 2001 max@suse.de
- Changed spec file to make use of %%{_libdir} where appropriate.
* Mon Dec 17 2001 max@suse.de
- Removed the START_POSTGRES variable from the fillup template
  and changed init script, and spec file to the new scheme.
- Moved the remaining variables from /etc/rc.config to
  /etc/sysconfig/postgresql.
* Wed Sep 12 2001 max@suse.de
- New version (patch release): 7.1.3
  The ChangeLog says:
  - Remove unused WAL segements of large transactions (Tom)
  - Multiaction rule fix (Tom)
  - Pl/pgSQL memory allocation fix (Jan)
  - VACUUM buffer fix (Tom)
  - Regression test fixes (Tom)
  - pg_dump fixes for GRANT/REVOKE/comments on views,
    user-defined types (Tom)
  - Fix subselects with DISTINCT ON or LIMIT (Tom)
  - BEOS fix
  - Disable COPY TO/FROM a view (Tom)
  - Cygwin build (Jason Tishler)
- Fixed bug in init script.
  It needed a file that comes only with postgresql-devel
- Better Patch for PgTcl. It now sets the client encoding to
  UNICODE (PostgreSQL's name for UTF-8) for Tcl versions >= 8.1
  instead of using Tcl's conversion functions to get the correct
  string representation.
- Added README.SuSE (only german, so far)
- Some minor typo fixes in the spec file.
* Mon Aug 27 2001 utuerk@suse.de
- removed postgresql.conf (now provided by susehelp)
* Mon Jul 23 2001 max@suse.de
- Fixed %%pre and %%post scripts for YaST.
* Thu Jul 19 2001 max@suse.de
- fixed regression tests for SPARC32.
- fixed init script to warn about incompatible data files.
- added patch for Pgtcl to use UTF8 for internal string
  representation if compiled with Tcl >= 8.1 .
- added pkgIndex.tcl to allow dynamic loading of Pgtcl using
  Tcl's package mechanism.
* Wed Jul 11 2001 max@suse.de
- fixed regression test to succeed on PPC with glibc-2.2.3 .
* Tue Jul 10 2001 max@suse.de
- new version: 7.1.2
- packages again based on the official PostgreSQL RPMs.
- architecture patches are no longer needed.
- running the regression tests as part of the build process to
  ensure that only correctly built binaries get packed in.
- new subpackages: contrib, doc
- renamed subpackage lib to libs to conform to the official RPMs
- ToDo: (semi)automatic conversion for updates
  from versions prior 7.1.
* Mon May  7 2001 mfabian@suse.de
- bzip2 sources
* Fri Apr 27 2001 max@suse.de
- updated the init script to be more LSB compliant according to
  the current /etc/init.d/skeleton.
* Thu Apr 12 2001 max@suse.de
- fix for deprecated declarations in readline 4.2.
- fixed permissons of some shared objects for the backend.
- recovered timestamps of sources.
* Wed Apr 11 2001 utuerk@suse.de
- added postgresql.conf for susehelp
* Thu Mar 22 2001 ro@suse.de
- added split-aliases as provides
* Wed Mar 21 2001 poeml@suse.de
- 7.0.* does not work on PPC unless compiled with -O0 (7.1 will)
* Wed Mar  7 2001 max@suse.de
- added xshared and xdevel to neededforbuild
  because X is no longer in the default buildsystem.
* Thu Feb 22 2001 ro@suse.de
- added readline/readline-devel to neededforbuild (split from bash)
* Wed Jan 24 2001 max@suse.de
- added missing "Provides:" entries to specfile.
* Mon Jan 15 2001 max@suse.de
- dropping the locale environment vars from the init script
  as workarround for a locale related bug in the backend.
  It shows up when the regression test runs on a backend that
  has e.g. LC_CTYPE=de_DE .
* Wed Nov 29 2000 max@suse.de
- new version: 7.0.3
- spec file is based on Lamar Owen's source RPM of
  PostgreSQL-7.0.3 for SuSE Linux 7.0
- renamed the whole package
    postgres -> postgresql
    pg_lib   -> postgresql-lib
    pg_serv  -> postgresql-serv
    pg_devel -> postgresql-devel
    pg_tcl   -> postgresql-tcl
    pg_tk    -> postgresql-tk
    pg_odbc  -> postgresql-odbc
    pg_jdbc  -> postgresql-jdbc
    pg_pyth  -> postgresql-python
    pg_perl  -> postgresql-perl
    pg_test  -> postgresql-test
- renamed some files and scripts from *postgres* to *postgresql*
- moved to the LSB-compliant init scheme
- moved database initialisation from SuSEconfig.postgres
  into the init script
- changed postgresql-python to use Python2.0 instead of 1.5
* Sat Oct 28 2000 kukuk@suse.de
- Add python-devel to need for build
* Mon Oct 23 2000 bk@suse.de
- integrated change from max:
- changed /sbin/init.d/postgres and SuSEconfig.postgres
  to work arround YaST that quotes the value of POSTGRES_DATADIR
  in /etc/rc.config when it gets changed.
* Mon Sep 11 2000 fober@suse.de
- made postgres run&autobuild on s390:
- src/include/port/linux.h, src/include/storage/s_lock.h:
  s390-assembler test-and-set (thanks to Andreas Jaeger)
- src/template/.similar, src/template/linux_s390:
  created linux_s390-Template from linux_ppc.
  TODO: is -O0 really needed?
- regression test passes (with minor deviations in floating point
  arithmetics)
  TODO: the regression test will not run out of the box as we install
  it.  this is the missing piece, either in postgres-source or in
  .spec
  [#] missing files
  cd $BUILD_ROOT/usr/src/packages/BUILD/postgresql-7.0.2/;
  cp -avP src/backend/*.h $RPM_BUILD_ROOT/usr/lib/pgsql
  cp -avP src/include $RPM_BUILD_ROOT/usr/lib/pgsql
  cp -avP src/Makefile.port $RPM_BUILD_ROOT/usr/lib/pgsql
  cp -avP src/Makefile.global $RPM_BUILD_ROOT/usr/lib/pgsql
  [#] directory structure
  cd $RPM_BUILD_ROOT/usr/lib/pgsql
  mkdir src
  mv test src
  ln -s src/test .
* Mon Aug 28 2000 max@suse.de
- changed installation order to fix bug #3802
* Mon Jul  3 2000 max@suse.de
- Disabled fcntl(F_SETLK) on the postmaster socket to work arround
  a kernel bug in Linux <= 2.2.16.
- New subpackage: pg_lib contains the shared libs for C and C++.
* Thu Jun 29 2000 schwab@suse.de
- Fix spinlocks for ia64.
- Reenable ia64 patch on the other architectures.
* Wed Jun 28 2000 max@suse.de
- disabled the ia64 patch when building for other architectures
- database unload+reload on updates works now
- moved some script and config files out of the diff into
  source files of their own.
- template database creation moved from init script into SuSEconfig
- some minor cleanups
* Tue Jun 20 2000 schwab@suse.de
- Add support for ia64.
* Fri Jun  9 2000 max@suse.de
- New version: 7.0.2.
- Re-made the whole package based on the original PostgreSQL RPM.
- There is still a little work needed for clean updates from
  PostgreSQL 6.x to 7.0.x
- Heavy testing needed before SuSE Linux 7.0.
* Sun Apr  9 2000 bk@suse.de
- added suse update config macro
- added automake to list of packages needed for building postgres
* Thu Feb 10 2000 ke@suse.de
- add more source files from the official PostgreSQL package.
- start to apply patches from there.
- start to cleanup the spec file.
- start to resolve bug #1948.
* Wed Feb  9 2000 ke@suse.de
- add group tag.
- ./configure -> %%build.
- New default for rc.config variable START_POSTGRES ("no").
* Fri Dec 10 1999 ke@suse.de
- update: version 6.5.3.
- startup script: use -S to remove the socket.
* Tue Oct 12 1999 ro@suse.de
- added tcld to neededforbuild
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Aug  2 1999 ke@suse.de
- postgresql init script: remove the socket in /tmp before trying to
  start the postmaster.
* Thu Jul 29 1999 ke@suse.de
- update: version 6.5.1.
* Tue Jul 20 1999 ke@suse.de
- remove MANPATH setting from /etc/postgres.{sh,csh} and from
  /etc/pg_ifa.{sh,csh}.
- provide manpage links at /usr/share/man:
    /usr/lib/pgsql/man/man?/*.?.gz -> /urs/share/man/man?/*.?.pgsql.gz
- now, you'll find all manpage in "pg_ifa".
* Thu Mar 18 1999 ke@suse.de
- compile an install "spi" (on popular demand...).
* Wed Feb 10 1999 ke@suse.de
- security fix: don't create pg_pwd with mode 666 (thanks to mt).
* Mon Feb  1 1999 ke@suse.de
- fix permissions of libs (thanks to mt).
* Fri Jan  8 1999 ke@suse.de
- update: version 6.4.2.
* Tue Dec  1 1998 ke@suse.de
- add /etc/profile.d/{postgres,pg_ifa}.csh (thanks to werner).
- new bootscript (thanks to werner).
* Fri Nov 27 1998 ke@suse.de
- link libpgtcl against libcrypt.
* Thu Nov 12 1998 bs@suse.de
- fixed spec file for new rpm.
* Fri Oct 30 1998 ke@suse.de
- update: version 6.4-BETA4.
* Sun Sep 27 1998 ke@suse.de
- update: version pre6.4 (snapshot 1998-09-27).
- remove pgaccess (it's a separate package now).
- all libraries and binaries are under the separate hierarchy
  /usr/lib/pgsql (on customers' request...).
- provide /etc/profile.d/{postgres,pg_ifa}.sh; .csh files are still
  missing.
* Mon Aug 24 1998 ke@suse.de
- shut down the postmaster before uninstalling.
* Tue Aug 18 1998 ke@suse.de
- add pgaccess' GIFs (HTML documentation).
* Sat Jul 25 1998 ke@suse.de
- Use `-n postgres' to make the `%%post' script available.
* Mon Jul 13 1998 ke@suse.de
- update pgaccess: version 0.88.
* Thu May 28 1998 ke@suse.de
- New package split: rip out the base interfaces (libraries and database
  tools); the new package is called pg_ifa (subpackage).
- update pgaccess: version 0.87.
* Fri May 22 1998 ke@suse.de
- update: version 6.3.2
- package split to ease maintainability and user updates; now, we've the
  following packages:
  postgres : base packages, essential interfaces included (libpq,
  libpq++, libpqtcl and PgAccess).
  pg_datab : initial database (needed only for the first
  installation or in case of major number updates); if
  not installed, the user has to invoke `initdb'
  manually.
  pg_iface : PostgreSQL interfaces (Perl, JDBC, more to come...).
* Thu May  7 1998 fehr@suse.de
- add library -lXp for Motif 2.1
* Wed Feb 11 1998 fehr@suse.de
- added the perl interface
* Wed Dec 10 1997 ro@suse.de
- build static and dynamic version of dbbrowser and mpsql
* Wed Dec  3 1997 ro@suse.de
- fixed /sbin/init.d/postgres (path, db-path, read rc.config)
  moved logfile to /var/log
* Tue Nov 18 1997 bs@suse.de
- skipped man3/abort.3.gz
* Tue Nov  4 1997 fehr@suse.de
- changed to version 6.2.1 of the new postgresSQL
- changed to version 1.5 of mpsql
- changed to version 0.2 of AppGEN
- added version 0.9 if dbbrowser
- prepare package for automatic build
- home Directory of postgrs user must now be /var/lib/postgres
- this Change is a major step since postgres95 it is possible
  that some changes are incompatible with the previos postgres
  versions.
* Mon Jun  9 1997 fehr@suse.de
- make symbolic link in /usr/doc/packages relative
* Sun Jun  1 1997 bs@suse.de
- moved fillup stuff to var/adm/fillup-templates
* Mon May 12 1997 fehr@suse.de
- added startup-script for /sbin/init.d
- added fillup for /etc/rc.config START_POSTGRES
